facilities/intercept.hpp

The facilities/intercept.hpp header defines a utility macro to intercept a numeric concatenation.

#### Usage

#include <boost/preprocessor/facilities/intercept.hpp>

#### Contents

- BOOST_PP_INTERCEPT

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)